pub struct Socket { /* private fields */ }Implementations
Sourceimpl Socket
A socket that represents a unique TCP connection between a server and client.
impl Socket
A socket that represents a unique TCP connection between a server and client.
The Socket object itself satisfies Sync and Send, which means it can
be safely called within an async future.
To close a TCP connection that is no longer needed, simply drop this object out of scope.